package com.ruoyi.shipping.mapper;

import com.ruoyi.shipping.domain.TShipDealItem;

import java.util.List;

/**
 * 凯和费用协议明细Mapper接口
 * 
 * @author ruoyi
 * @date 2022-01-07
 */
public interface TShipDealItemMapper 
{
    /**
     * 查询凯和费用协议明细
     * 
     * @param fId 凯和费用协议明细ID
     * @return 凯和费用协议明细
     */
    public TShipDealItem selectTShipDealItemById(Long fId);

    /**
     * 查询凯和费用协议明细列表
     * 
     * @param tShipDealItem 凯和费用协议明细
     * @return 凯和费用协议明细集合
     */
    public List<TShipDealItem> selectTShipDealItemList(TShipDealItem tShipDealItem);

    /**
     * 新增凯和费用协议明细
     * 
     * @param tShipDealItem 凯和费用协议明细
     * @return 结果
     */
    public int insertTShipDealItem(TShipDealItem tShipDealItem);

    /**
     * 修改凯和费用协议明细
     * 
     * @param tShipDealItem 凯和费用协议明细
     * @return 结果
     */
    public int updateTShipDealItem(TShipDealItem tShipDealItem);

    /**
     * 删除凯和费用协议明细
     * 
     * @param fId 凯和费用协议明细ID
     * @return 结果
     */
    public int deleteTShipDealItemById(Long fId);

    /**
     * 批量删除凯和费用协议明细
     * 
     * @param fIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTShipDealItemByIds(Long[] fIds);
    /**
     * 批量删除凯和费用协议明细
     *
     * @param fIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTShipDealItemByPIds(Long[] fIds);
}
